@@ -2,12 +2,12 @@
 
 import numpy as np
 import sys
-import test_numpy_compile_pyd_multi
+import test_numpy_setuptools_multi
 
 def func(a, b):
     say_hello(a)
     ret_list(a, b)
-    result = np.sqrt(test_numpy_compile_pyd_multi.multiplication(int(a), int(b)))
+    result = np.sqrt(test_numpy_setuptools_multi.multiplication(int(a), int(b)))
     return result
 
 
